@@ -12,7 +12,7 @@ from argparse import (
     _SubParsersAction,
 )
 from collections import defaultdict, namedtuple
-from typing import Iterator, Set, cast
+from typing import Iterator, cast
 
 from docutils.nodes import (
     Element,
@@ -25,9 +25,10 @@ from docutils.nodes import (
     paragraph,
     reference,
     section,
+    strong,
     title,
 )
-from docutils.parsers.rst.directives import unchanged, unchanged_required
+from docutils.parsers.rst.directives import positive_int, unchanged, unchanged_required
 from docutils.parsers.rst.states import RSTState, RSTStateMachine
 from docutils.statemachine import StringList
 from sphinx.util.docutils import SphinxDirective
@@ -47,6 +48,7 @@ class SphinxArgparseCli(SphinxDirective):
         "func": unchanged_required,
         "prog": unchanged,
         "title": unchanged,
+        "usage_width": positive_int,
     }
 
     def __init__(
@@ -99,6 +101,7 @@ class SphinxArgparseCli(SphinxDirective):
 
     def run(self) -> list[Node]:
         # construct headers
+        self.env.note_reread()  # this document needs to be always updated
         title_text = self.options.get("title", f"{self.parser.prog} - CLI interface").strip()
         if title_text.strip() == "":
             home_section: Element = paragraph()
@@ -136,46 +139,57 @@ class SphinxArgparseCli(SphinxDirective):
 
     def _mk_option_line(self, action: Action, prefix: str) -> list_item:  # noqa
         line = paragraph()
+        as_key = action.dest
+        if action.metavar:
+            as_key = action.metavar if isinstance(action.metavar, str) else action.metavar[0]
         if action.option_strings:
             first = True
+            is_flag = action.nargs == 0
             for opt in action.option_strings:
                 if first:
                     first = False
                 else:
                     line += Text(", ")
-                ref_id = make_id(f"{prefix}-{opt}")
-                ref = reference("", refid=ref_id)
-                line.attributes["ids"].append(ref_id)
-                ref += literal(text=opt)
-                line += ref
+                self._mk_option_name(line, prefix, opt)
+                if not is_flag:
+                    line += Text(" ")
+                    line += literal(text=as_key.upper())
         else:
-            as_key = (
-                action.dest
-                if action.metavar is None
-                else (action.metavar if isinstance(action.metavar, str) else action.metavar[0])
-            )
-            ref_id = make_id(f"{prefix}-{as_key}")
-            ref = reference("", refid=ref_id)
-            line.attributes["ids"].append(ref_id)
-            ref += literal(text=as_key)
-            line += ref
+            self._mk_option_name(line, prefix, as_key)
+
         point = list_item("", line, ids=[])
         if action.help:
+            help_text = load_help_text(action.help)
+            temp = paragraph()
+            self.state.nested_parse(StringList(help_text.split("\n")), 0, temp)
             line += Text(" - ")
-            line += Text(action.help)
-        if action.default != SUPPRESS:
+            for content in cast(paragraph, temp.children[0]).children:
+                line += content
+        if action.default != SUPPRESS and not re.match(r".*[ (]default[s]? .*", (action.help or "")):
             line += Text(" (default: ")
             line += literal(text=str(action.default).replace(os.getcwd(), "{cwd}"))
             line += Text(")")
         return point
 
+    @staticmethod
+    def _mk_option_name(line: paragraph, prefix: str, opt: str) -> None:
+        ref_id = make_id(f"{prefix}-{opt}")
+        ref = reference("", refid=ref_id)
+        line.attributes["ids"].append(ref_id)
+        st = strong()
+        st += literal(text=opt)
+        ref += st
+        line += ref
+
     def _mk_sub_command(self, aliases: list[str], help_msg: str, parser: ArgumentParser) -> section:
         title_text = f"{parser.prog}"
         if aliases:
             title_text += f" ({', '.join(aliases)})"
         group_section = section("", title("", Text(title_text)), ids=[make_id(title_text)], names=[title_text])
-        if help_msg:
-            desc_paragraph = paragraph("", Text(help_msg))
+
+        command_desc = (parser.description or help_msg or "").strip()
+        if command_desc:
+            desc_paragraph = paragraph("", Text(command_desc))
             group_section += desc_paragraph
         group_section += self._mk_usage(parser)
         for group in parser._action_groups:  # noqa
@@ -185,10 +199,22 @@ class SphinxArgparseCli(SphinxDirective):
         return group_section
 
     def _mk_usage(self, parser: ArgumentParser) -> literal_block:
-        parser.formatter_class = lambda prog: HelpFormatter(prog, width=100)
+        parser.formatter_class = lambda prog: HelpFormatter(prog, width=self.options.get("usage_width", 100))
         texts = parser.format_usage()[len("usage: ") :].splitlines()
         texts = [line if at == 0 else f"{' ' * (len(parser.prog) + 1)}{line.lstrip()}" for at, line in enumerate(texts)]
         return literal_block("", Text("\n".join(texts)))
 
 
+SINGLE_QUOTE = re.compile(r"[']+(.+?)[']+")
+DOUBLE_QUOTE = re.compile(r'["]+(.+?)["]+')
+CURLY_BRACES = re.compile(r"[{](.+?)[}]")
+
+
+def load_help_text(help_text: str) -> str:
+    single_quote = SINGLE_QUOTE.sub("``'\\1'``", help_text)
+    double_quote = DOUBLE_QUOTE.sub('``"\\1"``', single_quote)
+    literal_curly_braces = CURLY_BRACES.sub("``{\\1}``", double_quote)
+    return literal_curly_braces
+
+
 __all__ = ("SphinxArgparseCli",)
